==> AttoContainer_src_1.0.0.zip: AttoContainer_src_1.0.0/TestAttoContainer/Form1.cs <==
using System;
using System.Text;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using TestAttoContainerLib.Logic;
using AttoContainer;

namespace TestAttoContainer
{
	/// <summary>
	/// Form1 ̊Tv̐łB
	/// </summary>
	public class Form1 : System.Windows.Forms.Form
	{
		/// <summary>
		/// KvȃfUCiϐłB
		/// </summary>
		private System.ComponentModel.Container components = null;
		private ITestLogic testLogic;

		public ITestLogic TestLogic 
		{
			set
			{
				testLogic = value;
			}
			get
			{
				return testLogic;
			}
		}

		public Form1()
		{
			//
			// Windows tH[ fUCi T|[gɕKvłB
			//
			InitializeComponent();

			//
			// TODO: InitializeComponent ĂяǒɁARXgN^ R[hǉĂB
			//
		}

		/// <summary>
		/// gpĂ郊\[XɌ㏈s܂B
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows tH[ fUCiŐꂽR[h 
		/// <summary>
		/// fUCi T|[gɕKvȃ\bhłB̃\bh̓e
		/// R[h GfB^ŕύXȂłB
		/// </summary>
		private void InitializeComponent()
		{
			// 
			// Form1
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(7, 15);
			this.ClientSize = new System.Drawing.Size(537, 363);
			this.Name = "Form1";
			this.Text = "Form1";
			this.Load += new System.EventHandler(this.Form1_Load);

		}
		#endregion

		/// <summary>
		/// AvP[ṼC Gg |CgłB
		/// </summary>
		[STAThread]
		static void Main() 
		{
			// DIContainer쐬
			DIContainer container = DIContainer.Instance("components.xml",Encoding.GetEncoding("utf-8"));
			// R|[lg擾
			Form1 form = (Form1)container.GetComponent(typeof(Form1));
			// DIContainerJ
			container.Dispose();

			// Ńu[N|CgŎ~߂form̒Ă݂ƁA
			// vpeBTestLogicTestAttoContainerLib.Logic.TestLogic
			// ̃CX^XInjectionĂ܂B
			// TestLogic̃vpeBTestDaoɂTestAttoContainerLib.Dao.TestDao
			// ̃CX^XInjectionĂ܂B
			Application.Run(form);
		}

		private void Form1_Load(object sender, System.EventArgs e)
		{
			// InjectionꂽtestLogicExecuteLogic\bhs܂B
			testLogic.ExecuteLogic();
		}
	}
}

==> AttoContainer_src_1.1.0.zip: AttoContainer_src_1.1.0/TestAttoContainer/Form1.cs <==
using System;
using System.Text;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using TestAttoContainerLib.Logic;
using AttoContainer;

namespace TestAttoContainer
{
	/// <summary>
	/// Form1 ̊Tv̐łB
	/// </summary>
	public class Form1 : System.Windows.Forms.Form
	{
		/// <summary>
		/// KvȃfUCiϐłB
		/// </summary>
		private System.ComponentModel.Container components = null;
		private ITestLogic testLogic;

		public ITestLogic TestLogic 
		{
			set
			{
				testLogic = value;
			}
			get
			{
				return testLogic;
			}
		}

		public Form1()
		{
			//
			// Windows tH[ fUCi T|[gɕKvłB
			//
			InitializeComponent();

			//
			// TODO: InitializeComponent ĂяǒɁARXgN^ R[hǉĂB
			//
		}

		/// <summary>
		/// gpĂ郊\[XɌ㏈s܂B
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows tH[ fUCiŐꂽR[h 
		/// <summary>
		/// fUCi T|[gɕKvȃ\bhłB̃\bh̓e
		/// R[h GfB^ŕύXȂłB
		/// </summary>
		private void InitializeComponent()
		{
			// 
			// Form1
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(7, 15);
			this.ClientSize = new System.Drawing.Size(537, 363);
			this.Name = "Form1";
			this.Text = "Form1";
			this.Load += new System.EventHandler(this.Form1_Load);

		}
		#endregion

		/// <summary>
		/// AvP[ṼC Gg |CgłB
		/// </summary>
		[STAThread]
		static void Main() 
		{
			// DIContainer쐬
			DIContainer container = DIContainer.Instance("../../components.xml",Encoding.GetEncoding("utf-8"));
			// R|[lg擾
			Form1 form = (Form1)container.GetComponent(typeof(Form1));
			// DIContainerJ
			container.Dispose();

			// Ńu[N|CgŎ~߂form̒Ă݂ƁA
			// vpeBTestLogicTestAttoContainerLib.Logic.TestLogic
			// ̃CX^XInjectionĂ܂B
			// TestLogic̃vpeBTestDaoɂTestAttoContainerLib.Dao.TestDao
			// ̃CX^XInjectionĂ܂B
			Application.Run(form);
		}

		private void Form1_Load(object sender, System.EventArgs e)
		{
			// InjectionꂽtestLogicExecuteLogic\bhs܂B
			testLogic.ExecuteLogic();
		}
	}
}
